@@ -143,7 +143,7 @@ def check_mongo_server_output(binary, argument):
                                 stderr=subprocess.STDOUT,
                                 stdout=subprocess.PIPE, shell=False)
     except OSError as exc:
-        print('Failed to launch %s' % binary)
+        print('Failed to launch %s: %s' % (binary, exc))
         raise exc
 
     out, err = proc.communicate()
@@ -665,9 +665,7 @@ class MLaunchTool(BaseCmdLineTool):
             raise SystemExit(errmsg)
 
         # add the 'csrs' parameter as default for MongoDB >= 3.3.0
-        if (LooseVersion(self.current_version) >= LooseVersion("3.3.0") or
-                LooseVersion(self.current_version) == LooseVersion("0.0.0")):
-            self.args['csrs'] = True
+        self.args['csrs'] = True
 
         # construct startup strings
         self._construct_cmdlines()
@@ -779,7 +777,7 @@ class MLaunchTool(BaseCmdLineTool):
                                                        ('name', name)]))
                         except Exception as e:
                             if self.args['verbose']:
-                                print('%s will retry in a moment.' % e)
+                                print('Shard addition failed: %s; will retry in a moment.' % e)
                             continue
 
                         if res['ok']:
@@ -789,7 +787,7 @@ class MLaunchTool(BaseCmdLineTool):
                                 break
                         else:
                             if self.args['verbose']:
-                                print(res + ' - will retry')
+                                print('Shard addition failed: ' + res + ' - will retry')
 
                     time.sleep(1)
 
@@ -1830,22 +1828,25 @@ class MLaunchTool(BaseCmdLineTool):
             return rs_status
         except OperationFailure:
             # not initiated yet
+            
+            if self.args['verbose']:
+                print("initializing replica set '%s' with configuration: %s"
+                      % (name, self.config_docs[name]))
+            
             for i in range(maxwait):
                 try:
                     con['admin'].command({'replSetInitiate':
                                           self.config_docs[name]})
                     break
                 except OperationFailure as e:
-                    print(str(e) + " - will retry")
+                    print('Replica set initialization failed: %s - will retry' % e)
                     time.sleep(1)
 
-            if self.args['verbose']:
-                print("initializing replica set '%s' with configuration: %s"
-                      % (name, self.config_docs[name]))
             print("replica set '%s' initialized." % name)
 
     def _add_user(self, port, name, password, database, roles):
         con = self.client('localhost:%i' % port, serverSelectionTimeoutMS=10000)
+        ismaster = con['admin'].command('isMaster')
         v = ismaster.get('maxWireVersion', 0)
         if v >= 7:
             # Until drivers have implemented SCRAM-SHA-256, use old mechanism.
@@ -2121,7 +2122,7 @@ class MLaunchTool(BaseCmdLineTool):
 
         auth_param = ''
         if self.args['auth']:
-            auth_param = '--auth'
+            auth_param = ''
             if '--keyFile' not in self.unknown_args:
                 key_path = os.path.abspath(os.path.join(self.dir, 'keyfile'))
                 auth_param = f'{auth_param} --keyFile "{key_path}"'
@@ -2176,7 +2177,7 @@ class MLaunchTool(BaseCmdLineTool):
 
         auth_param = ''
         if self.args['auth']:
-            auth_param = '--auth'
+            auth_param = ''
             if '--keyFile' not in self.unknown_args:
                 key_path = os.path.abspath(os.path.join(self.dir, 'keyfile'))
                 auth_param = f'{auth_param} --keyFile "{key_path}"'
